@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 from mopidy import config, ext
 
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 
 
 class Extension(ext.Extension):
@@ -18,8 +18,11 @@ class Extension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(Extension, self).get_config_schema()
+        schema['hash'] = config.String()
+        schema['use_album_mbid_uri'] = config.Boolean()
+        schema['use_artist_mbid_uri'] = config.Boolean()
+        schema['foreign_keys'] = config.Boolean()
         schema['timeout'] = config.Integer(optional=True, minimum=1)
-        schema['foreign_keys'] = config.Boolean(optional=True)
         return schema
 
     def setup(self, registry):
